==> bibx-0.2.0.tar.gz: bibx-0.2.0/src/bibx/__init__.py <==
import logging
from typing import TextIO

from bibx._entities.article import Article
from bibx._entities.collection import Collection
from bibx._entities.collection_builders.scopus_bib import ScopusBibCollectionBuilder
from bibx._entities.collection_builders.scopus_ris import ScopusRisCollectionBuilder
from bibx._entities.collection_builders.wos import WosCollectionBuilder
from bibx.algorithms.sap import Sap
from bibx.exceptions import BibXError

logger = logging.getLogger(__name__)

__all__ = [
    "Article",
    "Collection",
    "Sap",
    "read_scopus_bib",
    "read_scopus_ris",
    "read_wos",
    "read_any",
]

__version__ = "0.2.0"


def read_scopus_bib(*files: TextIO) -> Collection:
    """
    Takes any number of bibtex files from scopus and generates a collection.

    :param files: Scopus bib files open.
    :return: the collection
    """
    return ScopusBibCollectionBuilder(*files).build()


def read_scopus_ris(*files: TextIO) -> Collection:
    """
    Takes any number of ris files from scopus and generates a collection.

    :param files: Scopus bib files open.
    :return: the collection
    """
    return ScopusRisCollectionBuilder(*files).build()


def read_wos(*files: TextIO) -> Collection:
    """
    Takes any number of wos text files and returns a collection.

    :param files: WoS files open.
    :return: the collection
    """
    return WosCollectionBuilder(*files).build()


def read_any(file: TextIO) -> Collection:
    """
    Tries to read a file with the supported formats.
    """
    for handler in (read_wos, read_scopus_ris, read_scopus_bib):
        try:
            return handler(file)
        except BibXError as e:
            logger.debug(f"Error: {e}")
        except ValueError:
            logger.debug(
                f"Error: the {handler.__name__} function does not support this file"
            )
    raise ValueError("Unsupported file type")

==> bibx-0.3.1.tar.gz: bibx-0.3.1/src/bibx/__init__.py <==
"""BibX is a library to work with bibliographic data."""

import logging
from typing import TextIO

from bibx._entities.article import Article
from bibx._entities.collection import Collection
from bibx._entities.collection_builders.openalex import OpenAlexCollectionBuilder
from bibx._entities.collection_builders.scopus_bib import ScopusBibCollectionBuilder
from bibx._entities.collection_builders.scopus_ris import ScopusRisCollectionBuilder
from bibx._entities.collection_builders.wos import WosCollectionBuilder
from bibx.algorithms.sap import Sap
from bibx.exceptions import BibXError

logger = logging.getLogger(__name__)

__all__ = [
    "Article",
    "Collection",
    "Sap",
    "query_openalex",
    "read_any",
    "read_scopus_bib",
    "read_scopus_ris",
    "read_wos",
]

__version__ = "0.3.1"


def query_openalex(query: str, limit: int = 600) -> Collection:
    """Query OpenAlex and return a collection."""
    return OpenAlexCollectionBuilder(query, limit).build()


def read_scopus_bib(*files: TextIO) -> Collection:
    """Take any number of bibtex files from scopus and generates a collection.

    :param files: Scopus bib files open.
    :return: the collection
    """
    return ScopusBibCollectionBuilder(*files).build()


def read_scopus_ris(*files: TextIO) -> Collection:
    """Take any number of ris files from scopus and generates a collection.

    :param files: Scopus bib files open.
    :return: the collection
    """
    return ScopusRisCollectionBuilder(*files).build()


def read_wos(*files: TextIO) -> Collection:
    """Take any number of wos text files and returns a collection.

    :param files: WoS files open.
    :return: the collection
    """
    return WosCollectionBuilder(*files).build()


def read_any(file: TextIO) -> Collection:
    """Try to read a file with the supported formats."""
    for handler in (read_wos, read_scopus_ris, read_scopus_bib):
        try:
            return handler(file)
        except BibXError as e:
            logger.debug("Error: %s", e)
        except ValueError:
            logger.debug(
                "Error: the %s function does not support this file", handler.__name__
            )
    message = "Unsupported file type"
    raise ValueError(message)
